#ifndef _CRERROR_H_
#define _CRERROR_H_

namespace SCRSDK
{
	typedef CrInt32 CrError;
	enum
	{
		// 16bit	always 1
		// 9~15bit	category of error
		// 1~8bit	error detail in category
		CrError_None								= 0x0000,
		CrError_Generic								= 0x8000,
		CrError_Genric								= 0x8000, /* Do not use. Will be removed in the next release. */
		CrError_File								= 0x8100,
		CrError_Connect								= 0x8200,
		CrError_Memory								= 0x8300,
		CrError_Api									= 0x8400,
		CrError_Init								= 0x8500,
		CrError_Polling								= 0x8600,
		CrError_Adaptor								= 0x8700,
		CrError_Device								= 0x8800,
		CrError_Contents							= 0x8C00,
		CrError_Monitoring							= 0x9100,

		CrError_Application							= 0xc000, /* Do not use. Will be removed in the next release. */

		// Uncategorized
		CrError_Generic_Unknown						= CrError_Generic,
		CrError_Generic_Notimpl,
		CrError_Generic_Abort,
		CrError_Generic_NotSupported,
		CrError_Generic_SeriousErrorNotSupported,
		CrError_Generic_InvalidHandle,
		CrError_Generic_InvalidParameter,

		/* [START] Do not use. Will be removed in the next release. */
		CrError_Genric_Unknown						= CrError_Generic,
		CrError_Genric_Notimpl,
		CrError_Genric_Abort,
		CrError_Genric_NotSupported,
		CrError_Genric_SeriousErrorNotSupported,
		CrError_Genric_InvalidHandle,
		CrError_Genric_InvalidParameter,
		/* [END] Do not use. Will be removed in the next release. */

		// File related
		CrError_File_Unknown						= CrError_File,	
		CrError_File_IllegalOperation,
		CrError_File_IllegalParameter,
		CrError_File_EOF,
		CrError_File_OutOfRange,
		CrError_File_NotFound,
		CrError_File_DirNotFound,
		CrError_File_AlreadyOpened,
		CrError_File_PermissionDenied,
		CrError_File_StorageFull,
		CrError_File_AlreadyExists,
		CrError_File_TooManyOpenedFiles,
		CrError_File_ReadOnly,
		CrError_File_CantOpen,
		CrError_File_CantClose,
		CrError_File_CantDelete,
		CrError_File_CantRead,
		CrError_File_CantWrite,
		CrError_File_CantCreateDir,
		CrError_File_OperationAbortedByUser,
		CrError_File_UnsupportedOperation,
		CrError_File_NotYetCompleted,
		CrError_File_Invalid,
		CrError_File_StorageNotExist,
		CrError_File_SharingViolation,
		CrError_File_Rotation,
		CrError_File_SameNameFull,

		// Connection related
		CrError_Connect_Unknown						= CrError_Connect,
		CrError_Connect_Connect,
		CrError_Connect_ConnectIP,
		CrError_Connect_Release,
		CrError_Connect_GetProperty,
		CrError_Connect_SendCommand,
		CrError_Connect_HandlePlugin,
		CrError_Connect_Disconnected,
		CrError_Connect_TimeOut,
		CrError_Reconnect_TimeOut,
		CrError_Connect_FailRejected,
		CrError_Connect_FailBusy,
		CrError_Connect_FailUnspecified,
		CrError_Connect_Cancel,
		CrError_Reserved1,
		CrError_Reserved2,
		CrError_Connect_SessionAlreadyOpened,
		CrError_Connect_ContentsTransfer_NotSupported,
		CrError_Connect_SSH_NotSupported,
		CrError_Connect_SSH_InvalidParameter,
		CrError_Connect_SSH_ServerConnectFailed,
		CrError_Connect_SSH_ServerAuthenticationFailed,
		CrError_Connect_SSH_UserAuthenticationFailed,
		CrError_Connect_SSH_PortfowardFailed,	/* Do not use. Will be removed in the next release. */
		CrError_Connect_SSH_PortForwardFailed = CrError_Connect_SSH_PortfowardFailed,
		CrError_Connect_SSH_GetFingerprintFailed,

		//Memory related
		CrError_Memory_Unknown						= CrError_Memory,
		CrError_Memory_OutOfMemory,
		CrError_Memory_InvalidPointer,
		CrError_Memory_Insufficient,

		//API related
		CrError_Api_Unknown							= CrError_Api,
		CrError_Api_Insufficient,
		CrError_Api_InvalidCalled,
		CrError_Api_NoApplicableInformation,
		CrError_Api_OutOfModelList,
		CrError_Api_NotSupportModelOfUSB,
		CrError_Api_NotSupportModelOfEthernet,
		CrError_Api_InvalidSerialNumber,
		CrError_Api_InvalidIpAddress,	
		CrError_Api_InvalidMacAddress,
		CrError_Api_PasswordLengthOverMax,
		CrError_Api_PasswordIncludesInvalidCharacter,

		CrError_Polling_Unknown						= CrError_Polling,
		CrError_Polling_InvalidVal_Intervals,

		//Adaptor related
		CrError_Adaptor_Unknown						= CrError_Adaptor,
		CrError_Adaptor_InvaildProperty,  /* Do not use. Will be removed in the next release. */
		CrError_Adaptor_InvalidProperty = CrError_Adaptor_InvaildProperty,
		CrError_Adaptor_GetInfo,
		CrError_Adaptor_Create,
		CrError_Adaptor_SendCommand,
		CrError_Adaptor_HandlePlugin,
		CrError_Adaptor_CreateDevice,
		CrError_Adaptor_EnumDecvice,  /* Do not use. Will be removed in the next release. */
		CrError_Adaptor_EnumDevice = CrError_Adaptor_EnumDecvice,
		CrError_Adaptor_Reset,
		CrError_Adaptor_Read,
		CrError_Adaptor_Phase,
		CrError_Adaptor_DataToWiaItem,
		CrError_Adaptor_DeviceBusy,
		CrError_Adaptor_Escape,

		CrError_Device_Unknown						= CrError_Device,

		// [MTP] content transfer
		CrError_Contents_Unknown					= CrError_Contents,
		CrError_Contents_Reserved1,
		CrError_Contents_InvalidHandle,
		CrError_Contents_DateFolderList_NotRetrieved,
		CrError_Contents_ContentsList_NotRetrieved,
		CrError_Contents_Transfer_Unsuccess,
		CrError_Contents_Transfer_Cancel,
		CrError_Contents_RejectRequest,

		// Monitoring
		CrError_Monitoring_Unknown					= CrError_Monitoring,
		CrError_Monitoring_InvalidCalled_AlreadyStart,
		CrError_Monitoring_InvalidCalled_AlreadyStop,

		CrWarning_Unknown							= 0x00020000,
		CrWarning_Connect_Reconnected,
		CrWarning_Connect_Reconnecting,
		CrWarning_File_StorageFull,
		CrWarning_SetFileName_Failed,
		CrWarning_GetImage_Failed,
		CrWarning_FailedToSetCWB,/* Do not use. Will be removed in the next release. Use 'CrWarning_CustomWBCapture_Result_NG' instead.*/
		CrWarning_NetworkErrorOccurred,
		CrWarning_NetworkErrorRecovered,
		CrWarning_Format_Failed,
		CrWarning_Format_Invalid,
		CrWarning_Format_Complete,
		CrWarning_FTPTransferSetting_Read_Result_Invalid,
		CrWarning_FTPTransferSetting_Read_Result_OK,
		CrWarning_FTPTransferSetting_Read_Result_NG,
		CrWarning_FTPTransferSetting_Read_Result_NG_password,
		CrWarning_FTPTransferSetting_Read_Result_DeviceBusy,
		CrWarning_Exposure_Started, /* Do not use. Will be removed in the next release. */
		CrNotify_Captured_Event = CrWarning_Exposure_Started,
		CrWarning_DateTime_Setting_Result_Invalid,
		CrWarning_DateTime_Setting_Result_OK,
		CrWarning_DateTime_Setting_Result_Parameter_Error,
		CrWarning_DateTime_Setting_Result_Exclusion_Error,
		CrWarning_DateTime_Setting_Result_System_Error,
		CrWarning_Frame_NotUpdated,
		CrNotify_All_Download_Complete,
		CrWarning_Connect_Already,
		CrWarning_Connect_OverLimitOfDevice,
		CrWarning_Format_Canceled,
		CrWarning_ZoomAndFocusPosition_Invalid,
		CrWarning_ZoomAndFocusPosition_DifferentLens,
		CrWarning_ZoomAndFocusPosition_InvalidLens,
		CrWarning_ContentsTransferMode_Invalid,
		CrWarning_ContentsTransferMode_DeviceBusy,
		CrWarning_ContentsTransferMode_StatusError,
		CrWarning_ContentsTransferMode_CanceledFromCamera,
		CrWarning_ContentsTransferCancel_Success,
		CrWarning_ContentsTransferCancel_Error,
		CrNotify_ContentsTransfer_Start,
		CrNotify_ContentsTransfer_Complete,
		CrWarning_CameraSettings_Read_Result_Invalid,
		CrWarning_CameraSettings_Read_Result_OK,
		CrWarning_CameraSettings_Read_Result_NG,
		CrWarning_CameraSettings_Save_Result_NG,
		CrWarning_RequestDisplayStringList_Success,
		CrWarning_RequestDisplayStringList_Error,
		CrWarning_DisplayListChanged_BaseLook_AELevelOffsetExposureValueList,
		CrWarning_DisplayListChanged_BaseLook_InputDisplayList,
		CrWarning_DisplayListChanged_BaseLook_NameDisplayList,
		CrWarning_DisplayListChanged_BaseLook_OutputDisplayList,
		CrWarning_DisplayListChanged_SceneFile_NameDisplayList,
		CrWarning_DisplayListChanged_ShootingMode_CinemaColorGamutDisplayList,
		CrWarning_DisplayListChanged_ShootingMode_TargetDisplayDisplayList,
		CrWarning_DisplayListChanged_Camera_GainBaseISODisplayList,
		CrWarning_DisplayListChanged_Video_EIGainDisplayList,
		CrWarning_DisplayListChanged_Button_AssignDisplayList,
		CrWarning_DisplayListChanged_Button_AssignShortDisplayList,
		CrWarning_MediaProfileChanged_Slot1,
		CrWarning_MediaProfileChanged_Slot2,
		CrWarning_LensInformationChanged,
		CrWarning_RequestLensInformation_Result_Success,
		CrWarning_RequestLensInformation_Result_DeviceBusy,
		CrWarning_RequestLensInformation_Result_Error,
		CrWarning_DisplayListChanged_CreativeLook_NameDisplayList,
		CrWarning_CustomWBCapture_Result_Invalid,
		CrWarning_CustomWBCapture_Result_OK,
		CrWarning_CustomWBCapture_Result_NG,
		CrWarning_ImportLUTFile_Result_Invalid,
		CrWarning_ImportLUTFile_Result_OK,
		CrWarning_ImportLUTFile_Result_NG,
		CrWarning_ImportLUTFile_Result_InvalidFileName,
		CrWarning_ImportLUTFile_Result_DeviceBusy,
		CrWarning_ImportLUTFile_Result_DeviceStorageFull,
		CrWarning_ImportLUTFile_Result_InvalidParameter,
		CrWarning_ImportLUTFile_Result_InvalidFile,
		CrWarning_FTPTransferSetting_Save_Result_NG,
		CrWarning_FTPTransferSetting_Save_Result_DeviceBusy,
		CrWarning_FTPTransferSetting_SaveRead_PasswordLengthOverMax,
		CrWarning_FTPTransferSetting_SaveRead_PasswordIncludesInvalidCharacter,
		CrWarning_RequestFTPServerSettingList_Success,
		CrWarning_RequestFTPServerSettingList_DeviceBusy,
		CrWarning_RequestFTPServerSettingList_Error,
		CrWarning_SetFTPServerSetting_Result_Invalid,
		CrWarning_SetFTPServerSetting_Result_OK,
		CrWarning_SetFTPServerSetting_Result_NG,
		CrWarning_SetFTPServerSetting_Result_DeviceBusy,
		CrWarning_RequestFTPJobList_Result_Success,
		CrWarning_RequestFTPJobList_Result_DeviceBusy,
		CrWarning_RequestFTPJobList_Result_Error,
		CrWarning_ControlFTPJobList_Set_Result_Invalid,
		CrWarning_ControlFTPJobList_Set_Result_OK, 
		CrWarning_ControlFTPJobList_Set_Result_NG,
		CrWarning_ControlFTPJobList_Set_Result_DeviceBusy,
		CrWarning_ControlFTPJobList_Delete_Result_Invalid,
		CrWarning_ControlFTPJobList_Delete_Result_OK, 
		CrWarning_ControlFTPJobList_Delete_Result_NG,
		CrWarning_ControlFTPJobList_Delete_Result_DeviceBusy,
		CrWarning_ControlFTPJobList_Suspend_Result_Invalid,
		CrWarning_ControlFTPJobList_Suspend_Result_OK, 
		CrWarning_ControlFTPJobList_Suspend_Result_NG,
		CrWarning_ControlFTPJobList_Suspend_Result_DeviceBusy,
		CrWarning_ControlFTPJobList_Resume_Result_Invalid,
		CrWarning_ControlFTPJobList_Resume_Result_OK, 
		CrWarning_ControlFTPJobList_Resume_Result_NG,
		CrWarning_ControlFTPJobList_Resume_Result_DeviceBusy,
		CrWarning_MovieRecordingOperation_Result_Invalid,
		CrWarning_MovieRecordingOperation_Result_OK,
		CrWarning_MovieRecordingOperation_Result_NG,
		CrWarning_FocusPosition_Result_Invalid,
		CrWarning_FocusPosition_Result_OK,
		CrWarning_FocusPosition_Result_NG,
		CrWarning_Reserved1,
		CrWarning_DisplayListChanged_FTP_ServerNameDisplayList,
		CrWarning_DisplayListChanged_FTP_UpLoadDirectoryDisplayList,
		CrWarning_DisplayListChanged_FTP_JobStatusDisplayList,
		CrWarning_Reserved2,
		CrWarning_Reserved3,
		CrWarning_Reserved4,
		CrWarning_Reserved5,
		CrWarning_Reserved6,
		CrWarning_DisplayListChanged_IPTCMetadataDisplayList,
		CrWarning_DisplayListChanged_SubjectRecognitionAFDisplayList,
		CrWarning_Reserved9,
		CrWarning_MediaProfileChanged_Slot3,
		CrWarning_ControlMonitoring_Result_Start_Failed,
		CrWarning_ControlMonitoring_Result_Stop_Failed,
		CrWarning_ControlMonitoring_Result_Invalid,
		CrWarning_ControlMonitoring_Result_SystemError,
		CrWarning_ControlMonitoring_Result_MaximumNumberSimultaneousDeliveries,
		CrWarning_ControlMonitoring_Result_ExclusiveError,
		CrWarning_ControlMonitoring_Result_AlreadyStartedInDifferentType,
		CrWarning_ControlMonitoring_Result_MonitoringStopped,
		CrWarning_ControlMonitoring_Result_InvalidParameter,
		CrWarning_ControlMonitoring_Result_Reserved1,
		CrWarning_ControlMonitoring_Result_Reserved2,
		CrWarning_ControlMonitoring_StatusChanged,
		CrWarning_ControlMonitoring_LostReceiving,
		CrWarning_RequestZoomAndFocusPreset_Result_Success,
		CrWarning_RequestZoomAndFocusPreset_Result_DeviceBusy,
		CrWarning_RequestZoomAndFocusPreset_Result_Error,
		CrWarning_ZoomAndFocusPresetChanged,
		CrWarning_CautionDisplay,
		CrNotify_FTPTransferResult_Success,
		CrNotify_FTPTransferResult_Failure,

		CrWarningExt_Unknown = 0x00060000,
		CrWarningExt_AFStatus,
		CrWarningExt_OperationResults,
	};

	enum CrWarningExt_AFStatusParam : CrInt32
	{
		CrWarningExt_AFStatusParam_Unlocked             = 0x00000001,
		CrWarningExt_AFStatusParam_Focused_AF_S         = 0x00000002,
		CrWarningExt_AFStatusParam_NotFocused_AF_S      = 0x00000003,
		CrWarningExt_AFStatusParam_TrackingSubject_AF_C = 0x00000005,
		CrWarningExt_AFStatusParam_Focused_AF_C         = 0x00000006,
		CrWarningExt_AFStatusParam_NotFocused_AF_C      = 0x00000007,
	};

	enum CrWarningExt_OperationResultsParam : CrInt32
	{
		CrWarningExt_OperationResultsParam_Invalid = 0x00000000,
		CrWarningExt_OperationResultsParam_OK,
		CrWarningExt_OperationResultsParam_NG,
		CrWarningExt_OperationResultsParam_InvalidParameterError,
		CrWarningExt_OperationResultsParam_CameraStatusError,
		CrWarningExt_OperationResultsParam_CharacterSizeError = 0x00000011,
	};

	#define CR_SUCCEEDED(e)	(SCRSDK::CrError_None == (e))
	#define CR_FAILED(e)	(SCRSDK::CrError_None != (e))
}

#endif //_CRERROR_H_
